# Colors

A Python package providing custom color palettes and themes for data visualization with matplotlib and seaborn.

## Installation

```bash
pip install .
```

## Usage

### Basic Usage

```python
# Import the required modules
import colors.mpl as mpl
import colors.colors as colors

# Set the theme (available themes: carbonplan_light)
mpl.set_theme(style='carbonplan_light')

# Load colors into your local namespace
lcs = locals()
lcs.update(**colors.light)

# Now you can use the colors in your plots
import matplotlib.pyplot as plt
import seaborn as sns

# Example with scatter plot using predefined colors
plt.scatter(*zip(*cluster_1), color=red, label='Cluster 1')

# Example with heatmap using custom colormaps
sns.heatmap(city_corr_matrix, annot=True, cmap='redteal_light_r', center=0, ax=ax)
```

### Available Themes
- `carbonplan_light`

### Available Color Palettes
The package provides color palettes through the `colors.light` module. Colors can be accessed directly after updating the local namespace as shown in the usage example.

### Available Colormaps
- `redteal_light_r`: A reversed red-teal colormap suitable for correlation matrices and heatmaps

## Contributing

Contributions are welcome! Please feel free to submit a Pull Request.

## License

[MIT License](LICENSE)
